Crate bake_readme

Crate bake_readme 

Reusable readme.md maintenance tasks for Bake.

The task adds a short summary of recent entries from releases.md when a project readme.md does not already contain an authored Releases section. When the project root has a Cargo package manifest, it also adds or refreshes a generated package entry in the readme.md See Also section when the source repository link is not already present elsewhere in the readme.

Structs

PackageMetadata
Cargo package fields used to add a generated entry to the readme.md See Also section.
Release
A release entry parsed from the project’s releases.md file.

Functions

ensure_releases_section
Add the default Releases section if the document has no real Releases heading.
recent_releases
Parse the newest versioned release entries, excluding the Unreleased section.
update
Add recent release notes and Cargo package links to readme.md when needed.
update_document
Add or refresh metadata-derived See Also content and the standard Releases section.
update_document_with_releases
Add or refresh metadata-derived See Also content and recent release entries.
update_releases_section
Add or refresh a marked summary of the most recent releases.
update_task
Generated Bake task descriptor.