update_document

Function update_document 

pub fn update_document(
    document: &str,
    package: Option<&PackageMetadata>,
) -> String
Add or refresh metadata-derived See Also content and the standard Releases section.

The generated package entry is marked with an HTML comment so subsequent updates can refresh it while preserving the rest of a project-owned section.